const http = require('http');
const { expect } = require('chai');
const mocks = require('../../mocks');
const abby = require('../../index')({ tags: [], apiEndpoint: 'dummy' }, mocks.synchroniser);
/**
 * integration spec that validates the correct setting of the cookies
 */

function request({ address, port }) {
    return new Promise((resolve, reject) => {
        http.get(`http://${address}:${port}`, (res) => {
            resolve(res);
        }).on('error', reject);
    });
}

describe('cookie test', () => {
    let server;
    beforeEach(() => abby.ready());
    beforeEach((done) => {
        server = http.createServer((req, res) => {
            abby(req, res);
            res.writeHead(200, { 'Content-Type': 'text/plain' });
            res.write('Hello World!');
            res.end();
        }).listen(0, 'localhost');
        server.on('listening', done);
    });
    afterEach((done) => {
        server.close(done);
    });

    it('should set x-abby-version header', async () => {
        let response = await request(server.address());
        let value = response.headers['x-abby-version'];
        expect(value).not.to.be.undefined;
    });

    it('should set the x-abby-sync header', async () => {
        let response = await request(server.address());
        let value = response.headers['x-abby-sync'];
        expect(value).not.to.be.undefined;
    });
});