const chai = require('chai');
const spies = require('chai-spies');
const expect = chai.expect;
const Logger = require('../lib/logger');
chai.use(spies);

describe('logger', () => {
    let logger;

    describe('setLogger', () => {
        let newLogger = {
            log: () => {},
            debug: () => {},
            error: () => {},
        };

        beforeEach(() => {
            logger = Logger.instance(newLogger);
        });
        it('should set logger', () => {
            expect(logger.transport).to.equal(newLogger);
        });
        
        it('should use newLogger log for log', () => {
            let spy = chai.spy.on(newLogger, 'log');
            logger.log('data');
            expect(spy).to.have.been.called.with('data');
        });

        it('should use newLogger debug for debug', () => {
            let spy = chai.spy.on(newLogger, 'debug');
            logger.debug('data');
            expect(spy).to.have.been.called.with('data');
        });

        it('should use newLogger error for error', () => {
            let spy = chai.spy.on(newLogger, 'error');
            logger.error('data');
            expect(spy).to.have.been.called.with('data');
        });
    });
    describe('log', () => {
        let spy;
        beforeEach(() => {
            spy = chai.spy.on(console, 'log');
            logger = Logger.instance();
            logger.log('data');
        });

        it('should call all console.log with data', () => {
            expect(spy).to.have.been.called.with('data');
        });
    });
    describe('debug', () => {
        let spy;
        beforeEach(() => {
            spy = chai.spy.on(console, 'debug');
            logger = new Logger();
            logger.debug('data');
        });

        it('should call all console.debug with data', () => {
            expect(spy).to.have.been.called.with('data');
        });
    });
    describe('error', () => {
        let spy;
        beforeEach(() => {
            spy = chai.spy.on(console, 'error');
            logger = new Logger();
            logger.error('data');
        });

        it('should call all console.error with data', () => {
            expect(spy).to.have.been.called.with('data');
        });
    });
});
